qratio.msm(x, ind1, ind2, covariates = "mean")msmc(1,2).c(2,1)."mean", denoting the means of the covariates in
the data (this is the default),
the number 0, indicating that all the covariates sestimate and se, containing the
estimate and standard error respectively of the ratio of intensities.disease.msm with a
health state (state 1) and a disease state
(state 2). In this case, the progression rate is the (1,2) entry of
the intensity matrix, and the recovery rate is the (2,1) entry.
Thus to compute this ratio with covariates set to their means, we
call qratio.msm(disease.msm, c(1,2), c(2,1)) .
Standard errors are estimated by the delta method.
qmatrix.msm