sojourn.msm(x, covariates="mean", ci=c("delta","normal","bootstrap"), cl=0.95, B=1000)msm"mean", denoting the means of the covariates in
the data (this is the default),
the number 0, indicating that all the covariates"delta" (the default) then confidence intervals are
calculated by the delta method, or by simple transformation of the
Hessian in the very simplest cases.
If "normal", then calculate a confidence interval by deltamethod to find approximate standard errors.
Confidence limits are estimated by assuming normality on the log
scale.msm, qmatrix.msm, deltamethod